@@ -86,7 +86,7 @@
 #define KI18N_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KI18N_NO_DEPRECATED
-#  define KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54f00
+#  define KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55200
 #endif
 #ifdef KI18N_NO_DEPRECATED_WARNINGS
 #  define KI18N_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KI18N_DEPRECATED_WARNINGS_SINCE KI18N_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KI18N_DEPRECATED_WARNINGS_SINCE 0x54f00
+#    define KI18N_DEPRECATED_WARNINGS_SINCE 0x55200
 #  endif
 #endif
 
@@ -118,5 +118,12 @@
 #define KI18N_DEPRECATED_VERSION_5(minor, text)      KI18N_DEPRECATED_VERSION_5_##minor(text)
 #define KI18N_DEPRECATED_VERSION(major, minor, text) KI18N_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KI18N_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KI18N_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
+#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
+#  define KI18N_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) KI18N_DEPRECATED_VERSION(major, minor, text)
+#  define KI18N_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KI18N_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#else
+#  define KI18N_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
+#  define KI18N_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
+#endif
 
 #endif /* KI18N_EXPORT_H */
